function selRes = SPS_RA(id,selWin,rxHist)
% Resource allocation: SPS in V2X
% Implemented by Suhua Tang @ UEC 
% Input
%   id    : node ID
%   selWin: a window of resource for selection
%   rxHist: a matrix recording packet receiving info
%     [time, RSSI, TX-Id, TX-resource, TX-resource reservation]
%     column 1: time
%     column 2: RSSI
%     column 3: TX-Id
%     column 4: TX-resource
%     column 5: TX-resource reservation
% Output
%   selRes: resource selected from selWen
minT = selWin(1);
maxT = selWin(2);
interval = maxT - minT + 1;

% compute average RSSI
avgRSSI = zeros(interval, 1);
for idx=1:numel(avgRSSI)
    rssiSet = [];
    for t = minT+idx-1 - (interval:interval:interval*11)
        if (t<=0)
            break;
        end
        index = find(rxHist(:,1)==t);
        if ~isempty(index) && ~ismember(rxHist(index,3),[0,id])
            rssiSet = [rxHist(index,:); rssiSet];
        end
    end
    if ~isempty(rssiSet)
        avgRSSI(idx) = mean(rssiSet(:,2));
    else
        avgRSSI(idx) = -80;
    end
end

% get reservation flag
resFlag = false(interval,1);
index = rxHist(:,5)>=minT & rxHist(:,5)<=maxT;
resResv = rxHist(index,5);
if ~isempty(resResv)
    resFlag(resResv - minT + 1) = true;     % change resource with probability 1.0
end

threshDbSet = -70:3:-40;
selIdx = -1;
for idx = 1:numel(threshDbSet)
    index = (avgRSSI <= threshDbSet(idx)) & ~resFlag;
    if (sum(index)>=numel(index)*0.2)
        break;
    end
end
resSet = minT:maxT;
resSet = resSet(index);
selIdx = randi([1, numel(resSet)]);
selRes = resSet(selIdx);
