function [frmIsOk, txTime, txRate, frmPDR] = get_FrmPropInfo(frmType, SNR_dB, rateType, paylSize, mac)
% For the purpose of test
%     frmType  = 3;
%     SNR_dB   = [0 6 5]';
%     rateType = 0;
%     paylSize = 1000;

% frmType:  RTS/CTS/DATA/ACK
% SNR_dB:   SNR in dB, single value or vector
% rateType: rate type for data frame payload part, find the best rate if not specified
% paylSize: data frame payload size in bytes


findBestRate = 0;
if rateType <= 0
	findBestRate = 1;
end


ber_table= get_ChannelBERTable;


if frmType==mac.frmRTS | frmType==mac.frmCTS | frmType==mac.frmACK | frmType==mac.frmCRQ
	if frmType~=mac.frmCRQ
		rateType= mac.RATE_2M;
	end;
	frmbits = mac.BRateBits(frmType);

	ber = zeros(size(SNR_dB));
	for si=1:length(SNR_dB)
		snr = SNR_dB(si);
		[minv, index] = min(abs(snr-ber_table(:,3))); % 3rd column of ber_table is SNR
		ber(si) = ber_table(index, rateType+3); % 4th-7th column corresponds to 1M, 2M, 5.5M & 11M
	end;

	FER_prob= 1 - (1-ber) .^ frmbits;
	frmIsErr= rand(size(SNR_dB)) < FER_prob;
	txTime  = mac.preamble + mac.SIFS + mac.BRateBits(frmType) / mac.BasicRate(rateType);
	txTime  = repmat(txTime, size(SNR_dB));
	txRate  = repmat(mac.DataRates(rateType), size(SNR_dB));
	frmPDR  = 1-FER_prob;

elseif frmType==mac.frmDATA
	frmPDR  = zeros(size(SNR_dB));
	txRate  = zeros(size(SNR_dB));


	findBestRate = 0;
	rateType = mac.RATE_55M;


	frmbits = mac.DHeadBits + paylSize*8;
	for si=1:length(SNR_dB)
		snr = SNR_dB(si);
		[minv, index] = min(abs(snr-ber_table(:,3)));

		if findBestRate ~= 0    %%%% rate not specified, find the best
			ber = ber_table(index, 4:7); % 1M, 2M, 5.5M, 11M
			FER = 1 - (1-ber) .^ frmbits;
			idx = FER<0.05;
			if sum(idx(mac.RATE_2M : mac.RATE_11M))==0
				bestRate = mac.DataRates(mac.RATE_2M);
				rateType = mac.RATE_2M;
				FER_prob = FER(mac.RATE_2M);
			else
				[maxv, index] = max(mac.DataRates(idx));
				bestRate = maxv;
				rateType = index;
				FER_prob = FER(index);
			end;
		else                    %%%% use the specified rate
			bestRate = mac.DataRates(rateType);
			ber = ber_table(index, rateType+3);
			FER_prob = 1 - (1-ber) .^ frmbits;
		end;

		frmPDR(si)  = 1-FER_prob;
		txRate(si)  = bestRate;
	end;

	frmIsErr = rand(size(SNR_dB)) < 1-frmPDR;
	txTime   = mac.preamble + mac.SIFS + mac.BRateBits(frmType) / mac.BasicRate(rateType) + frmbits ./ txRate;
end;
frmIsOk = ~frmIsErr;